@@ -54,7 +54,8 @@ private Q_SLOTS:
         const auto refArray = QJsonDocument::fromJson(ref.readAll()).array();
         QVERIFY(!refArray.isEmpty());
 
-        const auto resJson = JsonLdDocument::toJson(QVector<QVariant>({QVariant::fromValue(p)}));
+        const auto resJson =
+            JsonLdDocument::toJson(QList<QVariant>({QVariant::fromValue(p)}));
         if (refArray != resJson) {
             qWarning().noquote() << QJsonDocument(resJson).toJson();
         }
