@@ -20,7 +20,7 @@ public:
     QString givenName;
 };
 
-KITINERARY_MAKE_SIMPLE_CLASS(Person)
+KITINERARY_MAKE_CLASS(Person)
 KITINERARY_MAKE_PROPERTY(Person, QString, name, setName)
 KITINERARY_MAKE_PROPERTY(Person, QString, email, setEmail)
 KITINERARY_MAKE_PROPERTY(Person, QString, familyName, setFamilyName)
