@@ -26,6 +26,7 @@
 
 #include <cmath>
 
+using namespace Qt::Literals;
 using namespace KItinerary;
 
 void PdfPagePrivate::load()
@@ -43,9 +44,12 @@ void PdfPagePrivate::load()
 #if KPOPPLER_VERSION < QT_VERSION_CHECK(25, 1, 0)
     std::unique_ptr<GooString> s(device.getText(pageRect->x1, pageRect->y1, pageRect->x2, pageRect->y2));
     m_text = QString::fromUtf8(s->c_str());
-#else
+#elif KPOPPLER_VERSION <QT_VERSION_CHECK(25, 12, 90)
     const auto s = device.getText(pageRect->x1, pageRect->y1, pageRect->x2, pageRect->y2);
     m_text = QString::fromUtf8(s.c_str());
+#else
+    const auto s = device.getText(PDFRectangle(pageRect->x1, pageRect->y1, pageRect->x2, pageRect->y2));
+    m_text = QString::fromUtf8(s.c_str());
 #endif
 
     m_images = std::move(device.m_images);
@@ -110,14 +114,18 @@ QString PdfPage::textInRect(double left, double top, double right, double bottom
             return {};
     }
 
-    TextOutputDev device(nullptr, false, 0, false, false);
+    TextOutputDev device(nullptr, true, 0, false, false);
+    device.setTextEOL(eolUnix);
     d->m_doc->m_popplerDoc->displayPageSlice(&device, d->m_pageNum + 1, 72, 72, rotate, false, true, false, -1, -1, -1, -1);
-#if KPOPPLER_VERSION <QT_VERSION_CHECK(25, 1, 0)
+#if KPOPPLER_VERSION < QT_VERSION_CHECK(25, 1, 0)
     std::unique_ptr<GooString> s(device.getText(l, t, r, b));
     return QString::fromUtf8(s->c_str());
-#else
+#elif KPOPPLER_VERSION <QT_VERSION_CHECK(25, 12, 90)
     const auto s = device.getText(l, t, r, b);
     return QString::fromUtf8(s.c_str());
+#else
+    const auto s = device.getText(PDFRectangle(l, t, r, b));
+    return QString::fromUtf8(s.c_str());
 #endif
 }
 
@@ -242,7 +250,12 @@ PdfDocument::~PdfDocument() = default;
 QString PdfDocument::text() const
 {
     QString text;
-    std::for_each(d->m_pages.begin(), d->m_pages.end(), [&text](const PdfPage &p) { text += p.text(); });
+    std::ranges::for_each(d->m_pages, [&text](const PdfPage &p) {
+        if (!text.isEmpty() && !text.endsWith('\n'_L1)) {
+            text += '\n'_L1;
+        }
+        text += p.text();
+    });
     return text;
 }
 
