@@ -9,8 +9,4 @@
 #include <config-kitinerary.h>
 #include <qglobal.h>
 
-#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 82, 0)
 using PopplerMaskColors = const int;
-#else
-using PopplerMaskColors = int;
-#endif
