@@ -4,7 +4,7 @@
 function extractPdf(pdf, node, barcode) {
     const text = pdf.pages[barcode.location].text;
     let res = JsonLd.newLodgingReservation();
-    const name = text.match(/(.*)\n.*: (.*)\n/);
+    const name = text.match(/(.*)\n+.*: (.*)\n/);
     res.reservationFor.name = name[2];
     res.underName.name = name[1];
     const dates = text.match(/(\d{2}\.\d{2}\.\d{4})\s+(\d{2}\.\d{2}\.\d{4})/);
