@@ -62,8 +62,8 @@ function parsePdfTicket(pdf, node, triggerNode)
     let idxStations = 0;
     let reservations = [];
     while (true) {
-        const times = timeColumn.substr(idxTime).match(/(\d\d:\d\d)\n([^:]*?\n)?([^:]*?\n)?(\d\d:\d\d)/);
-        const stations = stationColumn.substr(idxStations).match(/(?:\n|^)([^].*)\n[ ]+(.*)(?:\n|(,?\n  +.*)\n)(?:.*(?:NOTE:|Wagennummerierung|platform|The regional part|Die Bussteignummer|Operated|Platform).(?:.*\n)+?)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta)\s+(\S.+)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n(?:.*Lda\.\n)?)?(.*)\n(?:[ ]+(.*?)(?:\n|(,\n +.*)\n))?/);
+        const times = timeColumn.substr(idxTime).match(/(\d\d:\d\d)\n+([^:]*?\n)?([^:]*?\n)?(\d\d:\d\d)/);
+        const stations = stationColumn.substr(idxStations).match(/(?:\n|^)([^].*)\n[ ]+(.*)(?:\n+|(,?\n+  +.*)\n+)(?:.*(?:NOTE:|Wagennummerierung|platform|The regional part|Die Bussteignummer|Operated|Platform).(?:.*\n+)+?)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta)\s+(\S.+)\n+.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n+(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n+(?:.*Lda\.\n+)?)?(.*)\n+(?:[ ]+(.*?)(?:\n+|(,\n +.*)\n+))?/);
         if (!times || !stations) {
             break;
         }
