@@ -215,11 +215,11 @@ function parseSecutixPdfItineraryV1(text, res)
     var reservations = new Array();
     var pos = 0;
     while (true) {
-        var dep = text.substr(pos).match(/Départ [^ ]+ (\d+\.\d+\.\d+) à (\d+:\d+) [^ ]+ (.*)\n/);
+        const dep = text.substr(pos).match(/Départ \S+ (\d+\.\d+\.\d+) à (\d+:\d+) \S+ (.*)\n/);
         if (!dep)
             break;
         pos += dep.index + dep[0].length;
-        var arr = text.substr(pos).match(/Arrivée [^ ]+ (\d+\.\d+\.\d+) à (\d+:\d+) [^ ]+ (.*)\n\s+(.*)\n/);
+        const arr = text.substr(pos).match(/Arrivée \S+ (\d+\.\d+\.\d+) à (\d+:\d+) \S+ (.*)\n\s*(.*)/);
         if (!arr)
             break;
         pos += arr.index + arr[0].length;
@@ -245,7 +245,7 @@ function parseSecutixPdfItineraryV2(text, res)
     let reservations = [];
     let pos = 0;
     while (true) {
-        const trip = text.substr(pos).match(/ *(\d\dh\d\d)\n(.*)\n(.*)\n([\S\s]*?) *(\d\dh\d\d)\n(.*)\n/);
+        const trip = text.substr(pos).match(/ *(\d\dh\d\d)\n(.*)\n+(.*)\n+([\S\s]*?) *(\d\dh\d\d)\n(.*)\n/);
         if (!trip)
             break;
         pos += trip.index + trip[0].length;
