@@ -32,6 +32,7 @@
 #include <cassert>
 #include <cstring>
 
+using namespace Qt::Literals;
 using namespace KItinerary;
 
 namespace KItinerary {
@@ -86,6 +87,7 @@ QVariant Uic9183Parser::block(const QString &name) const
     BLOCK_FROM_NAME(Vendor0080BLBlock)
     BLOCK_FROM_NAME(Vendor0080VUBlock)
     BLOCK_FROM_NAME(Vendor1154UTBlock)
+    BLOCK_FROM_NAME(Vendor3697OTBlock)
 
 #undef BLOCK_FROM_NAME
 
@@ -368,13 +370,22 @@ Person Uic9183Parser::person() const
             return p;
         }
     }
+
     // CD vender block
-    if (const auto b = findBlock<Vendor1154UTBlock>(); b.isValid()) {
-        const auto subBlock = b.findSubBlock("KJ");
-        if (!subBlock.isNull()) {
-            Person p;
-            p.setName(subBlock.toString());
-            return p;
+    struct {
+        const char *block;
+        const char subBlock[3];
+    } constexpr const cz_keys[] = {
+        { Vendor1154UTBlock::RecordId, "KJ"},
+        { Vendor3697OTBlock::RecordId, "JP"}
+    };
+    for (const auto &key : cz_keys) {
+        if (const auto b = Vendor1154UTBlock(findBlock(key.block)); b.isValid()) {
+            if (const auto subBlock = b.findSubBlock(key.subBlock); !subBlock.isNull()) {
+                Person p;
+                p.setName(subBlock.toString());
+                return p;
+            }
         }
     }
 
