@@ -8,12 +8,14 @@
 #include "uic9183block.h"
 #include "logging.h"
 
+#include <string.h>
+
 using namespace KItinerary;
 
 int Uic9183Utils::readAsciiEncodedNumber(const char* data, int size, int offset, int length)
 {
     if (!data || offset < 0 || length < 1 || size < 1 || offset + length > size) {
-        qCWarning(Log) << "Invalid UIC 918.3 read" << offset << length << size;
+        qCWarning(Log) << "Invalid UIC 918.3 number read" << offset << length << size;
         return {};
     }
 
@@ -42,11 +44,11 @@ QString Uic9183Utils::readUtf8String(const char* data, int size, int offset, int
     }
 
     if (!data || offset < 0 || length < 1 || size < 1 || offset + length > size) {
-        qCWarning(Log) << "Invalid UIC 918.3 read" << offset << length << size;
+        qCWarning(Log) << "Invalid UIC 918.3 string read" << offset << length << size;
         return {};
     }
 
-    return QString::fromUtf8(data + offset, length);
+    return QString::fromUtf8(data + offset, strnlen(data + offset, length));
 }
 
 QString Uic9183Utils::readUtf8String(const QByteArray& data, int offset, int length)
