@@ -5,8 +5,9 @@
 */
 
 #include "../lib/asn1/berelement.h"
+#include "../lib/era/dosipas1.h"
+#include "../lib/era/dosipas2.h"
 #include "../lib/era/elbticket.h"
-#include "../lib/era/fcbticket.h"
 #include "../lib/era/ssbv1ticket.h"
 #include "../lib/era/ssbv2ticket.h"
 #include "../lib/era/ssbv3ticket.h"
@@ -39,6 +40,20 @@
 
 using namespace KItinerary;
 
+static void dumpRawData(const char *data, std::size_t size)
+{
+    bool isText = true;
+    for (std::size_t i = 0; i < size && isText; ++i) {
+        isText = (uint8_t)*(data + i) >= 20;
+    }
+
+    if (isText) {
+        std::cout.write(data, size);
+    } else {
+        std::cout << "(hex) " << QByteArray(data, size).toHex().constData();
+    }
+}
+
 template <typename T>
 static void dumpGadget(const T *gadget, const char* indent = "")
 {
@@ -58,6 +73,11 @@ static void dumpGadget(const void *gadget, const QMetaObject *mo, const char* in
         const auto value = prop.readOnGadget(gadget);
         if (prop.isEnumType()) {
             std::cout << indent << prop.name() << ": " << prop.enumerator().valueToKey(value.toInt()) << std::endl;
+        } else if (prop.typeId() == QMetaType::QByteArray) {
+            std::cout << indent << prop.name() << ": ";
+            const auto data = value.toByteArray();
+            dumpRawData(data.constData(), data.size());
+            std::cout << std::endl;
         } else {
             std::cout << indent << prop.name() << ": " << qPrintable(value.toString()) << std::endl;
         }
@@ -159,20 +179,6 @@ static void dumpElbTicket(const ELBTicket &ticket)
     }
 }
 
-static void dumpRawData(const char *data, std::size_t size)
-{
-    bool isText = true;
-    for (std::size_t i = 0; i < size && isText; ++i) {
-        isText = (uint8_t)*(data + i) >= 20;
-    }
-
-    if (isText) {
-        std::cout.write(data, size);
-    } else {
-        std::cout << "(hex) " << QByteArray(data, size).toHex().constData();
-    }
-}
-
 static void dumpUic9183(const QByteArray &data)
 {
     Uic9183Parser parser;
@@ -237,6 +243,12 @@ static void dumpUic9183(const QByteArray &data)
     }
 }
 
+template <typename T>
+static void dumpDosipas(const T &ticket)
+{
+    dumpGadget(&ticket, "  ");
+}
+
 static void dumpVdv(const QByteArray &data)
 {
     VdvTicketParser parser;
@@ -394,6 +406,12 @@ int main(int argc, char **argv)
     } else if (auto ticket = ELBTicket::parse(data); ticket) {
         std::cout << "ERA ELB Ticket" << std::endl;
         dumpElbTicket(*ticket);
+    } else if (auto ticket = Dosipas::v2::UicBarcodeHeader(data); ticket.isValid()) {
+        std::cout << "DOSIPAS v2 Container" << std::endl;
+        dumpDosipas(ticket);
+    } else if (auto ticket = Dosipas::v1::UicBarcodeHeader(data); ticket.isValid()) {
+        std::cout << "DOSIPAS v1 Container" << std::endl;
+        dumpDosipas(ticket);
     } else {
         std::cout << "Unknown content" << std::endl;
         return 1;
